# templateman
A simple project template manager written in Python.

Create Python scripts to automate boilerplate code creation, project templates, or other tasks. Templateman provides a simple CLI for managing these scripts.

See [examples](docs/examples.md) for more info.
